$TITLE Model de echilibru general Romania, AP 2014-2020, calibrat 2013
$OFFUPPER
$ONEMPTY

*$OFFLISTING
*$OFFSYMXREF
*$OFFSYMLIST

;

*################## 1. Versiune model ################################
$ontext


Proiect Implementarea Planului de Evaluare a Acordului de Parteneriat
- faza 2
Lot 1: Evaluarea contributiei la coeziunea economica, sociala si teritorial
- Tema A

Primul Raport de Evaluare 2022
Al doilea Raport de Evaluare 2023
Model - versiune finala
$offtext



*################## 2. Declaratii parametri, variabile ##############################


SETS

 sac(*)           SAM conturi

 c(sac)           conturile de bunuri si servicii
 a(sac)           conturile de activitati economice
 f(sac)           conturile factorilor
 h(sac)           conturile gospodariilor
 e(sac)           conturile intreprinderilor
 g(sac)           conturile guvernului
 i(sac)           conturile de capital
 w(sac)           conturile cu restul lumii
 m(sac)           conturile de mediu

* Declarare seturi ce se vor calcula din date

 ce(c)            bunuri si servicii exportate
 cen(c)           bunuri si servicii neexportate

 cm(c)            bunuri si servicii importate
 cmn(c)           bunuri si servicii neimportate

 cx(c)            bunuri si servicii din productia domestica
 cxn(c)           bunuri si servicii nu din productia domestica importate

 cd(c)            bunuri si servicii din productia domestica si cerute intern
 cdn(c)           bunuri si servicii nu din productia domestica si necerute intern

 cme(c)           poluare emisii GHG
 cmen(c)          ne poluare

* Productia

 acx(a)           activitati achizitii domestic
 acxn(a)          activitati nu achizitii domestic

 ame(a)           poluare emisii GHG
 amen(a)          ne poluare

 flab(f)          forta de munca
 flabn(f)         capital
* Alte seturi auxiliare

 SACN(SAC)        SAM conturi fara TOTAL

* ASAM pentru verificari si validare

 ss(*)            ASAM categorii
 ssn(ss)          ASAM conturi fara TOTAL



 SS  ASAM categorii /
                          COMMDTY       Conturile de bunuri si servicii
                          ACTIVITY      Conturile de activitati economice
                          VALUAD        Conturile valorii adaugate factorilor
                          HHOLDS        Conturile gospodariilor
                          ENTER         Conturile intreprinderilor
                          GOVTN         Conturile guvernului
                          KAPITAL       Conturile de capital
                          WORLD         Conturile cu restul lumii
                          ENVIR         Conturile de mediu
                          TOTALS        Venituri si Cheltuieli Totaluri      /

            ;



 ALIAS(sac,sacp,sacpp), (sacn,sacnp), (ss,ssp),
      (c,cp), (cm,cmp), (cmn,cmnp), (ce,cep), (cen,cenp),
      (a,ap),
      (f,fp),
      (h,hp), (e,ep), (g,gp), (i,ip), (m,mp),
      (w,wp) ;


 ALIAS(ss,ssp), (ssn,ssnp);

* DECLARARE PARAMETRI

PARAMETER

 SAM(sac,sacp)       SAM pentru model
 SAMR(sac,sac)       baza SAM pentru Romania

 FACTUSE(f,a)        Utilizarea factorilor pe activitati economice
 scaling             Factor scalare pentru viteza de calcul a algoritmului

* Elasticitati pentru bunuri si servicii
 ELASTC(c,*)         Elasticitatea de substitutie pentru bunuri si servicii comert

* Elasticitati pentru cererea de bunuri si servicii a gospodariilor
 ELASTY(c,h)         Elasticitatea in functie de venit
 ELASTMU(h,*)        Elasticitatea marginala a venitului

* Elasticitati pentru functia CES
 ELASTX(a,*)         Elasticitatea de substitutie intre factori

* Coeficientul de emisie pentru GHG
 MEDIU(*)         coeficient emisie Co2

*Cheltuieli de CDI pentru progres tehnologic
 PT(a,*)            Cheltuieli de CDI pentru stocul de cunostinte

    ;

*################## 3. Initializare, ajustare, scalare SAM ################

* Datele sunt preluate dintr-un fisier

$INCLUDE ro_date.inc

* Definire seturi excludere total

* Conturi SAM exclusiv totaluri
 SACN(SAC)     = YES ;
 SACN("total") = NO  ;

* Conturi ASAM exclusiv totaluri
 ssn(ss)       = YES ;
 ssn("totals") = NO ;

Display SAM, elastc, elasty, elastmu, elastx, mediu ;

Display sac, sacn, c, a, f, h, e, g, i, w, m, ss, ssn ;

* Ajustari de date
* Transferuri de date nete cu restul lumii

 SAM(h,"row")    = SAM(h,"row") + (-1 * SAM("row",h)) ;

 SAM("row",h)    = 0.0 ;

 SAM(e,"row")    = SAM(e,"row") + (-1 * SAM("row",e)) ;

 SAM("row",e)    = 0.0 ;

 SAM(g,"row")    = SAM(g,"row") + (-1 * SAM("row",g)) ;

 SAM("row",g)    = 0.0 ;

 SAM(f,"row")    = SAM(f,"row") + (-1 * SAM("row",f)) ;

 SAM("row",f)    = 0.0 ;

 SAM(i,"row")    = SAM(i,"row") + (-1 * SAM("row",i)) ;

 SAM("row",i)    = 0.0 ;

 SAM(m,"row")    = SAM(m,"row") + (-1 * SAM("row",m)) ;

 SAM("row",m)    = 0.0 ;
* Recalculare SAM totaluri

 SAM("total",sacnp)   = SUM(sacn,SAM(sacn,sacnp)) ;
 SAM(sacn,"total")    = SUM(sacnp,SAM(sacn,sacnp)) ;

 PARAMETER CHECKSAM ;
 CHECKSAM = SUM(sacn,(ABS(SAM(sacn,"TOTAL")-SAM("TOTAL",sacn)))) ;
 display checksam ;
 ABORT $(CHECKSAM GT 0.000005)
 "Diferente linii coloane", CHECKSAM, SAM ;

* Scalare SAM

PARAMETER
* Verificare date scalare

 MAXV       Valoarea maxima absoluta a tranzaciilor in SAM
 MINV       Valoarea minima absoluta a tranzaciilor in SAM

  ;

 MAXV      = SMAX((sac,sacp),ABS (SAM(sac,sacp))) ;
 MINV      = SMIN((sac,sacp)$SAM(sac,sacp),ABS (SAM(sac,sacp))) ;

 option decimals = 5 ;

DISPLAY MAXV, MINV ;

* Factor scalare

 scaling        = 10000 ;

* Scalare pentru imbunatatirea performantei algorimilor de calibrare

 SAM(sac,sacp)  = SAM(sac,sacp)/scaling ;
 FACTUSE(f,a)   = FACTUSE(f,a)/scaling ;

DISPLAY SAM, FACTUSE ;

*################## 4. Verificare date #############################

PARAMETER
* construire SAM agregat pentru verificare si calibrare
* ASAM0, ASAM1 si ASAM2 pentru verificari suplimentare

 ASAM0(ss,ss)   SAM agregat pentru verificare date intrare
 ASAM1(ss,ss)   SAM agregat pentru verificare date calibrare
 ASAM2(ss,ss)   SAM agregat pentru verificare solutie baza
 ASAM3(ss,ss)   SAM agregat pentru verificare solutie simulata
  ;

* Verificare SAM pentru a identifica eventuale tranzactii imposibile


 ASAM0("COMMDTY","COMMDTY")   = SUM((c,cp),SAM(c,cp)) ;
 ASAM0("COMMDTY","ACTIVITY")  = SUM((c,a),SAM(c,a)) ;
 ASAM0("COMMDTY","VALUAD")    = SUM((c,f),SAM(c,f)) ;
 ASAM0("COMMDTY","HHOLDS")    = SUM((c,h),SAM(c,h)) ;
 ASAM0("COMMDTY","ENTER")       = SUM((c,e),SAM(c,e)) ;
 ASAM0("COMMDTY","GOVTN")     = SUM((c,g),SAM(c,g)) ;
 ASAM0("COMMDTY","KAPITAL")   = SUM((c,i),SAM(c,i)) ;
 ASAM0("COMMDTY","WORLD")     = SUM((c,w),SAM(c,w)) ;
 ASAM0("COMMDTY","ENVIR")     = SUM((c,m),SAM(c,m)) ;

 ASAM0("ACTIVITY","COMMDTY")  = SUM((a,c),SAM(a,c)) ;
 ASAM0("ACTIVITY","ACTIVITY") = SUM((a,ap),SAM(a,ap)) ;
 ASAM0("ACTIVITY","VALUAD")   = SUM((a,f),SAM(a,f)) ;
 ASAM0("ACTIVITY","HHOLDS")   = SUM((a,h),SAM(a,h)) ;
 ASAM0("ACTIVITY","ENTER")      = SUM((a,e),SAM(a,e)) ;
 ASAM0("ACTIVITY","GOVTN")    = SUM((a,g),SAM(a,g)) ;
 ASAM0("ACTIVITY","KAPITAL")  = SUM((a,i),SAM(a,i)) ;
 ASAM0("ACTIVITY","WORLD")    = SUM((a,w),SAM(a,w)) ;
 ASAM0("ACTIVITY","ENVIR")     = SUM((a,m),SAM(a,m)) ;

 ASAM0("VALUAD","COMMDTY")    = SUM((f,c),SAM(f,c)) ;
 ASAM0("VALUAD","ACTIVITY")   = SUM((f,a),SAM(f,a)) ;
 ASAM0("VALUAD","VALUAD")     = SUM((f,fp),SAM(f,fp)) ;
 ASAM0("VALUAD","HHOLDS")     = SUM((f,h),SAM(f,h)) ;
 ASAM0("VALUAD","ENTER")        = SUM((f,e),SAM(f,e)) ;
 ASAM0("VALUAD","GOVTN")      = SUM((f,g),SAM(f,g)) ;
 ASAM0("VALUAD","KAPITAL")    = SUM((f,i),SAM(f,i)) ;
 ASAM0("VALUAD","WORLD")      = SUM((f,w),SAM(f,w)) ;
 ASAM0("VALUAD","ENVIR")     = SUM((f,m),SAM(f,m)) ;

 ASAM0("HHOLDS","COMMDTY")    = SUM((h,c),SAM(h,c)) ;
 ASAM0("HHOLDS","ACTIVITY")   = SUM((h,a),SAM(h,a)) ;
 ASAM0("HHOLDS","VALUAD")     = SUM((h,f),SAM(h,f)) ;
 ASAM0("HHOLDS","HHOLDS")     = SUM((h,hp),SAM(h,hp)) ;
 ASAM0("HHOLDS","ENTER")      = SUM((h,e),SAM(h,e)) ;
 ASAM0("HHOLDS","GOVTN")      = SUM((h, g),SAM(h,g)) ;
 ASAM0("HHOLDS","KAPITAL")    = SUM((h,i),SAM(h,i)) ;
 ASAM0("HHOLDS","WORLD")      = SUM((h,w),SAM(h,w)) ;
 ASAM0("HHOLDS","ENVIR")     = SUM((h,m),SAM(h,m)) ;

 ASAM0("ENTER","COMMDTY")       = SUM((e,c),SAM(e,c)) ;
 ASAM0("ENTER","ACTIVITY")      = SUM((e,a),SAM(e,a)) ;
 ASAM0("ENTER","VALUAD")        = SUM((e,f),SAM(e,f)) ;
 ASAM0("ENTER","HHOLDS")        = SUM((e,h),SAM(e,h)) ;
 ASAM0("ENTER","ENTER")           = SUM((e,ep),SAM(e,ep)) ;
 ASAM0("ENTER","GOVTN")         = SUM((e,g),SAM(e,g)) ;
 ASAM0("ENTER","KAPITAL")       = SUM((e,i),SAM(e,i)) ;
 ASAM0("ENTER","WORLD")         = SUM((e,w),SAM(e,w)) ;
 ASAM0("ENTER","ENVIR")     = SUM((e,m),SAM(e,m)) ;

 ASAM0("GOVTN","COMMDTY")     = SUM((g,c),SAM(g,c)) ;
 ASAM0("GOVTN","ACTIVITY")    = SUM((g,a),SAM(g,a)) ;
 ASAM0("GOVTN","VALUAD")      = SUM((g,f),SAM(g,f)) ;
 ASAM0("GOVTN","HHOLDS")      = SUM((g,h),SAM(g,h)) ;
 ASAM0("GOVTN","ENTER")         = SUM((g,e),SAM(g,e)) ;
 ASAM0("GOVTN","KAPITAL")     = SUM((g,i),SAM(g,i)) ;
 ASAM0("GOVTN","WORLD")       = SUM((g,w),SAM(g,w)) ;
 ASAM0("GOVTN","ENVIR")     = SUM((g,m),SAM(g,m)) ;

 ASAM0("KAPITAL","COMMDTY")   = SUM((i,c),SAM(i,c)) ;
 ASAM0("KAPITAL","ACTIVITY")  = SUM((i,a),SAM(i,a)) ;
 ASAM0("KAPITAL","VALUAD")    = SUM((i,f),SAM(i,f)) ;
 ASAM0("KAPITAL","HHOLDS")    = SUM((i,h),SAM(i,h)) ;
 ASAM0("KAPITAL","ENTER")       = SUM((i,e),SAM(i,e)) ;
 ASAM0("KAPITAL","GOVTN")     = SUM((i,g),SAM(i,g)) ;
 ASAM0("KAPITAL","KAPITAL")   = SUM((i,ip),SAM(i,ip)) ;
 ASAM0("KAPITAL","WORLD")     = SUM((i,w),SAM(i,w)) ;
 ASAM0("KAPITAL","ENVIR")     = SUM((i,m),SAM(i,m)) ;

 ASAM0("WORLD","COMMDTY")     = SUM((w,c),SAM(w,c)) ;
 ASAM0("WORLD","ACTIVITY")    = SUM((w,a),SAM(w,a)) ;
 ASAM0("WORLD","VALUAD")      = SUM((w,f),SAM(w,f)) ;
 ASAM0("WORLD","HHOLDS")      = SUM((w,h),SAM(w,h)) ;
 ASAM0("WORLD","ENTER")         = SUM((w,e),SAM(w,e)) ;
 ASAM0("WORLD","GOVTN")       = SUM((w,g),SAM(w,g)) ;
 ASAM0("WORLD","KAPITAL")     = SUM((w,i),SAM(w,i)) ;
 ASAM0("WORLD","WORLD")       = SUM((w,wp),SAM(w,wp)) ;
 ASAM0("WORLD","ENVIR")     = SUM((w,m),SAM(w,m)) ;

 ASAM0("ENVIR","COMMDTY")     = SUM((m,c),SAM(m,c)) ;
 ASAM0("ENVIR","ACTIVITY")    = SUM((m,a),SAM(m,a)) ;
 ASAM0("ENVIR","VALUAD")      = SUM((m,f),SAM(m,f)) ;
 ASAM0("ENVIR","HHOLDS")      = SUM((m,h),SAM(m,h)) ;
 ASAM0("ENVIR","ENTER")         = SUM((m,e),SAM(m,e)) ;
 ASAM0("ENVIR","GOVTN")       = SUM((m,g),SAM(m,g)) ;
 ASAM0("ENVIR","KAPITAL")     = SUM((m,i),SAM(m,i)) ;
 ASAM0("ENVIR","WORLD")       = SUM((m,wp),SAM(m,wp)) ;
 ASAM0("ENVIR","ENVIR")     = SUM((m,mp),SAM(m,mp)) ;




ASAM0("TOTALS",ssn)          = SUM(ssnp,ASAM0(ssnp,ssn)) ;
 ASAM0(ssn,"TOTALS")          = SUM(ssnp,ASAM0(ssn,ssnp)) ;


 ABORT $(ASAM0("COMMDTY","COMMDTY") NE 0.0)
 "ASAM0(COMMDTY,COMMDTY) non zero" ;

 ABORT $(ASAM0("COMMDTY","VALUAD") NE 0.0)
 "ASAM0(COMMDTY,VALUAD) non zero" ;

 ABORT $(ASAM0("ACTIVITY","ACTIVITY") NE 0.0)
 "ASAM0(ACTIVITY,ACTIVITY) non zero" ;

 ABORT $(ASAM0("ACTIVITY","VALUAD") NE 0.0)
 "ASAM0(ACTIVITY,VALUAD) non zero" ;

 ABORT $(ASAM0("ACTIVITY","HHOLDS") NE 0.0)
 "ASAM0(ACTIVITY,HHOLDS) non zero" ;

 ABORT $(ASAM0("ACTIVITY","GOVTN") NE 0.0)
 "ASAM0(ACTIVITY,GOVTN) non zero" ;

 ABORT $(ASAM0("ACTIVITY","KAPITAL") NE 0.0)
 "ASAM0(ACTIVITY,KAPITAL) non zero" ;

 ABORT $(ASAM0("ACTIVITY","WORLD") NE 0.0)
 "ASAM0(ACTIVITY,WORLD) non zero" ;

 ABORT $(ASAM0("VALUAD","COMMDTY") NE 0.0)
 "ASAM0(VALUAD,COMMDTY) non zero" ;

 ABORT $(ASAM0("VALUAD","VALUAD") NE 0.0)
 "ASAM0(VALUAD,VALUAD) non zero" ;

 ABORT $(ASAM0("VALUAD","HHOLDS") NE 0.0)
 "ASAM0(VALUAD,HHOLDS) non zero" ;

 ABORT $(ASAM0("VALUAD","GOVTN") NE 0.0)
 "ASAM0(VALUAD,GOVTN) non zero" ;

 ABORT $(ASAM0("VALUAD","KAPITAL") NE 0.0)
 "ASAM0(VALUAD,KAPITAL) non zero" ;

 ABORT $(ASAM0("HHOLDS","COMMDTY") NE 0.0)
 "ASAM0(HHOLDS,COMMDTY) non zero" ;

 ABORT $(ASAM0("HHOLDS","ACTIVITY") NE 0.0)
 "ASAM0(HHOLDS,ACTIVITY) non zero" ;

 ABORT $(ASAM0("HHOLDS","KAPITAL") NE 0.0)
 "ASAM0(HHOLDS,KAPITAL) non zero" ;

 ABORT $(ASAM0("GOVTN","KAPITAL") NE 0.0)
 "ASAM0(GOVTN,KAPITAL) non zero" ;

 ABORT $(ASAM0("KAPITAL","COMMDTY") NE 0.0)
 "ASAM0(KAPITAL,COMMDTY) non zero" ;

 ABORT $(ASAM0("KAPITAL","ACTIVITY") NE 0.0)
 "ASAM0(KAPITAL,ACTIVITY) non zero" ;

 ABORT $(ASAM0("WORLD","ACTIVITY") NE 0.0)
 "ASAM0(WORLD,ACTIVITY) non zero" ;

 ABORT $(ASAM0("WORLD","HHOLDS") NE 0.0)
 "ASAM0(WORLD,HHOLDS) non zero" ;

 ABORT $(ASAM0("WORLD","GOVTN") NE 0.0)
 "ASAM0(WORLD,GOVTN) non zero" ;

 ABORT $(ASAM0("WORLD","KAPITAL") NE 0.0)
 "ASAM0(WORLD,KAPITAL) non zero" ;

 ABORT $(ASAM0("WORLD","WORLD") NE 0.0)
 "ASAM0(WORLD,WORLD) non zero" ;


 PARAMETER CHECK0 ;
 CHECK0 = SUM(ssn,(ABS(ASAM0(ssn,"TOTALS")-ASAM0("TOTALS",ssn)))) ;

 OPTION DECIMALS=6 ;

DISPLAY CHECK0, ASAM0 ;

 ABORT $(CHECK0 GT 0.000005)
 "Diferente linii coloane" ;

*################## 5. Initializare ###################

* Definire pe baza datelor de intrare

 ce(c)       = YES$(SAM(c,"row")) ;
 cen(c)      = NOT ce(c) ;

 cm(c)       = YES$(SAM("row",c));
 cmn(c)      = not cm(c);

 cx(c)       = YES$(SUM(a,SAM(a,c))) ;
 cxn(c)      = not cx(c) ;

 cd(c)       = YES$( SUM(a,SAM(a,c)) GT (SAM(c,"row"))) ;
 cdn(c)      = not cd(c) ;

 acx(a)$(SUM(c, SAM(a,c)))      = YES ;
 acxn(a)                        = not acx(a) ;

 ame(a)      = YES$(SAM (a,"cmed"));
 amen(a)     = not ame(a);

 cme(c)      = YES$(SAM (c,"amed"));
 cmen(c)     = not cme(c);

 flab("flab1")     =YES ;
 flab("flab2")     =YES ;
 flab("flab3")     =YES ;
 flabn(f)      =not flab(f);

 DISPLAY ce, cen, cm, cmn, cx, cxn, cd, cdn,
         acx, acxn, ame, amen, cme, cmen, flab;


*################## 6. Calibrare model ###########################
* Pe blocuri

* ######## BLOCUL Preturilor normalizate

PARAMETERS

 PD0(c)        Pretul de consum pentru oferta domestica bunul c

 PEX0(c)        Pretul domestic al exporturilor din bunul c
 PIM0(c)        Pretul domestic al importurilor concurente pentru bunul c

 PP0(a)        Pretul de productie al activitatii a
 PPC0(c)       Pretul de productie al outputului compozit domestic c

 PPS0(c)       Pretul de productie al bunului compozit domestic c

 ER0           Cursul de schimb (intern pe extern)

   ;

* ## Initializare

 PD0(c)      = 1 ;

 PIM0(c)      = 1 ;
 PEX0(c)      = 1 ;

 PP0(a)      = 1 ;
 PPC0(c)     = 1 ;

 PPS0(c)     = 1 ;

 ER0         = 1 ;

* ######## BLOCUL Comertului exterior

* #### Blocul Exporturilor

PARAMETERS

 QEX0(c)         Productie domestica exportata din bunul c
 QD0(c)          Cererea interna pentru bunul c

 PWEX0(c)        Pretul exporturilor lume

* ## Parametri pentru functia CET

 rhot(c)        Parametru elasticitate output functia Armington CET
 gamma(c)       Parametru pondere pentru functia Armington CET
 at(c)          parametru shift pentru functia Armington CET

  ;

* ## Initializare

 QEX0(c)      = (SAM(c,"row"))/PEX0(c) ;


 QD0(c)      = (SUM(a,SAM(a,c))/PPC0(c)) - QEX0(c) ;

 PWEX0(c)$QEX0(c)
              = ((SAM(c,"row")/ER0)/QEX0(c)) ;

* ## Parametri pentru functiile CET

 rhot(c)$(cd(c) AND ce(c))    = (1/ELASTC(c,"omega")) + 1 ;

 gamma(c)$(cd(c) AND ce(c))
              = (PEX0(c)*QEX0(c)**(1-rhot(c)))
                 /(PEX0(c)*QEX0(c)**(1-rhot(c)) + PD0(c)*QD0(c)**(1-rhot(c))) ;

 at(c)$(cd(c) AND  ce(c))
              = (SUM(a,SAM(a,c))/PPC0(c))
                 /(gamma(c)*QEX0(c)**rhot(c) + (1-gamma(c))*
                       QD0(c)**rhot(c))**(1/rhot(c));

* #### Blocul Importurilor

PARAMETERS

 QIM0(c)         Import bunul c
 QC0(c)         Oferta bun compozit c

 PWIM0(c)        Pretul importurilor in lume

* ## Parameteri for Armington/CES functions

 ac(c)          Shift parameter for Armington CES function
 delta(c)       Share parameter for Armington CES function
 rhoc(c)        Elasticity parameter for Armington CES function

  ;

* ## Assignments

 QIM0(c)      = (SAM("row",c) + SAM("imptax",c))/PIM0(c) ;

 QC0(c)      = QD0(c) + QIM0(c) ;

 PWIM0(c)$QIM0(c)
              = (SAM("row",c)/ER0)/QIM0(c) ;

* ## Parametri functiii Armington

 rhoc(c)$(cx(c) AND cm(c))    = (1/ELASTC(c,"sigma")) - 1 ;

 delta(c)$(cd(c) AND cm(c))
               = (PIM0(c)*QIM0(c)**(rhoc(c)+1))
                  /(PIM0(c)*QIM0(c)**(rhoc(c)+1) + PD0(c)*QD0(c)**(rhoc(c)+1)) ;

 ac(c)$(cd(c) AND cm(c))
               = QC0(c)/(delta(c)*QIM0(c)**(-rhoc(c))
                         +(1-delta(c))*QD0(c)**(-rhoc(c)))**(-1/rhoc(c)) ;

* ######## Blocul preturilor bunurilor si serviciilor

PARAMETERS

 PAC0(c)       Pretul de achizitie al bunului compozit c

  ;

* ## Initializare

 PAC0(c)$QC0(c)
             = (SAM(c,"total") - SAM(c,"row")-SAM(c,"amed"))/QC0(c) ;

* ######## Blocul preturilor numitor

PARAMETERS

 comtotsh(c)     Ponderea bunului c in total cerere bunuri
 prodtotsh(c)    Ponderea bunului c in total productie domestica

 chkcomtotsh    verificare ponderi CPI
 chkprodtotsh    verificare ponderi PPI

 CPI0           Indicele preturilor de consum
 PPI0           Indicele preturilor de productie

  ;

* ## Initializare


 comtotsh(c)   = (SUM(h,SAM(c,h)) + SAM(c,"govt") + SAM(c,"i_s"))
                 /(SUM((cp,hp),SAM(cp,hp))
                  + SUM(cp,SAM(cp,"govt"))
                  + SUM(cp,SAM(cp,"i_s")))  ;

 chkcomtotsh    = SUM(c,comtotsh(c)) ;


 prodtotsh(c)   = SUM(a,SAM(a,c))/SUM((ap,cp),SAM(ap,cp)) ;

 chkprodtotsh   = SUM(c,prodtotsh(c)) ;

 CPI0         = SUM(c,comtotsh(c)*PAC0(c)) ;

 PPI0         = SUM(c,prodtotsh(c)*PD0(c)) ;

* ######## BLOCUL Productiei

PARAMETERS

 PP0(a)       Pretul compozit al productiei din activitatea a

 PVA0(a)      Pretul de vanzare pentru activitatea a

 QP0(a)       Productia domestica din activitatea a

 WF0(f)       Pretul factorului de productie f
 WFDIST0(f,a) Pretul factorilor - ponderi pe activitati
 WFDISTL0(a)   Pretul muncii - pondere pe activitati
 FD0(f,a)     Cererea pentru factorul f in activitatea a
 FDL0(a)      Cererea pentru munca in activitatea a
 FS0(f)       Oferta pentru factorul f
 FSL0         Oferta pentru munca total
 WFL0         Pretul muncii toate nivelurile de educatie total
* Cererea pentru consum intermediar

 QINTD0(c)    Cererea din bunul c pentru consumul intermediar

* Outputul

 QPC0(c)      Productia domestica pentru bunul c

* Functia de productie Cobb-Douglas / CES

* ad(a)        Parametru progres tehnologic functia de productie Cobb-Douglas
* alpha(f,a)   parametri ponderi functia de productie Cobb-Douglas

 rhova(a)       Parametru elasticitate
 adva(a)        Parametru progres tehnologic functia de productie CES
 deltava(a)    Parametri ponderi functia de productie CES

 rhoval(a)       Parametru elasticitate forta de munca
 adval(a)        Parametru progres tehnologic functia de productie CES forta de munca
 deltaval(f,a)   Parametri ponderi functia de productie CES  forta de munca

 iocoef(c,a) Coeficienti matricea utlizari resurse

 iocqa(a,c) Ponderea bunului c in outputul activitatii a

  ;

* #### Initializare


 QP0(a)$PP0(a)              = SAM("TOTAL",a)/PP0(a) ;
 QPC0(c)$PPC0(c)            = SUM(a,SAM(a,c))/PPC0(c) ;


 PVA0(a)$QP0(a)             =  SUM(f,SAM(f,a))/QP0(a) ;
 PVA0("amed")               = 0 ;
* QINTD0(c)$SUM(a,SAM(c,a))  = SUM(a,SAM(c,a)/PQD0(c)) ;

 FD0(f,a)                   = FACTUSE(f,a) ;
 FDL0(a)                    = FD0("flab1",a)  + FD0("flab2",a) +  FD0("flab3",a) ;
 FS0(f)                     = SUM(a,FACTUSE(f,a)) ;

 WF0(f)$FS0(f)              = SUM(a,SAM(f,a))/FS0(f) ;
 WFL0                       = (WF0("flab1")*FS0("flab1") +  WF0("flab2")*FS0("flab2")
                             +WF0("flab3")*FS0("flab3") ) / (FS0("flab1")+FS0("flab2")
                             +FS0("flab3"))  ;
 FSL0                       = FS0("flab1")+FS0("flab2")+FS0("flab3")  ;
 WFDIST0(f,a)$FD0(f,a)      = (SAM(f,a)/FD0(f,a))/WF0(f) ;

 WFDIST0(f,a)$(FD0(f,a) EQ 0)  = 0.0 ;
 WFDISTL0(a) $ FDL0(a)       = (SAM("flab1",a)+SAM("flab2",a)+SAM("flab3",a))/FDL0(a)/WFL0  ;
 WFDISTL0(a)$(FDL0(a) EQ 0)  = 0.0 ;

  QINTD0(c)$PAC0(c)          = (SUM(a,SAM(c,a))-SAM(c,"amed"))/PAC0(c) ;



* Cobb-Douglas

*alpha(f,a)$SUM(fp,SAM(fp,a))  = SAM(f,a)/SUM(fp,SAM(fp,a)) ;


*ad(a)        = QX0(a)/PROD(f, FD0(f,a)**alpha(f,a)) ;

*ioqintdqx(c,a)$(QX0(a) AND PQD0(c))
*               = (SAM(c,a)/PQD0(c))/QX0(a) ;



* CES nested
* CES munca-capital

 rhova(a)$amen(a)  = (1/ELASTX(a,"sigmava")) - 1 ;
 deltava(a)$amen(a) = (WF0("fres")*WFDIST0("fres",a)*(FD0("fres",a))**(1+rhova(a)))
               /(WF0("fres")*WFDIST0("fres",a)*(FD0("fres",a))**(1+rhova(a))+ (WFL0*WFDISTL0(a)*(FDL0(a))**(1+rhova(a)))) ;
 adva(a)$amen(a)   = QP0(a)/(deltava(a)*FD0("fres",a)**(-rhova(a))+(1-deltava(a))*FDL0(a)**(-rhova(a)))**(-1/rhova(a) );



* CES forta de munca

 rhoval(a)$amen(a)  = (1/ELASTX(a,"sigmaval")) - 1 ;
 deltaval(f,a)$(amen(a)and flab(f)) = (WF0(f)*WFDIST0(f,a)*(FD0(f,a))**(1+rhoval(a)))
               /SUM(fp,WF0(fp)*WFDIST0(fp,a)*(FD0(fp,a)) **(1+rhoval(a))) ;
 adval(a)$amen(a)   = FDL0(a)/(SUM(f,deltaval(f,a)*FD0(f,a)**(-rhoval(a))))**(-1/rhoval(a));



 iocoef(c,a)$(QP0(a) AND PAC0(c))
               = (SAM(c,a)/PAC0(c))/QP0(a) ;
* Output

 iocqa(a,c)$acx(a)        = SAM(a,c)/SUM(cp,SAM(a,cp)) ;

* ######## BLOCUL Factorilor

PARAMETERS

 YF0(f)        Venitul factorului f
 YFWOR0(f)     Venit factor f de la restul lumii
 YFDIST0(f)    Venitul distribuit pentru factorul f dupa depreciere

 hvash(h,f)    Ponderea din venitul de la factorul f pentru gospodaria h
 evash(f)      Ponderea venitului de la factorul f pentru intreprinderi
 gvash (f)     Ponderea venitului de la factorul f pentru guvern
 deprec(f)     Rata de depreciere a factrului f pe baza stocului factorului f

  ;

* ## Initializare

 YF0(f)       = SAM(f,"total") ;

 YFWOR0(f)    = SAM(f,"row") ;

 YFDIST0(f)   = (SAM("total",f) - SAM("i_s",f) - SAM("tcontrib",f)) ;

 deprec(f)$SAM("total",f)     = (SAM("i_s",f) + SAM("tcontrib",f)) /SAM("total",f) ;

 hvash(h,f)$SAM("total",f)    = SAM(h,f)/
                    (SAM("total",f) - SAM("i_s",f) - SAM("tcontrib",f)) ;

 evash(f)$SAM("total",f)    = SAM("ent",f)/
                    (SAM("total",f) - SAM("i_s",f) - SAM("tcontrib",f)) ;

 gvash(f)$SAM("total",f)    = SAM("govt",f)/
                    (SAM("total",f) - SAM("i_s",f) - SAM("tcontrib",f)) ;

* ######## BLOCUL Gospodariilor

PARAMETERS

 YH0(h)         Venitul gospodariei h

 HEXP0(h)       Cheltuiala pentru consum a gospodariei h

 QCH0(c,h)      Consumul gospodariei h din bunul c

 SHH0(h)        Ponderea din venit economisita de gospoadaria h (dupa taxare) initial

 SADJ0          Factor scalare rata de economisire

 shh(h)         Ponderea din venit economisita de gospoadaria h (dupa taxare)

 YHWOR0(h)      Remitente primite de gospodaria h

* ## Cheltuieli de consum
* # Functia de utilitate

 comhsh(c,h)    Ponderi consum gospodarii
 alphah(c,h)    Pondere cheltuiala per bun

* # Functia de utilitate Stone-Geary

 sumelast(h)    Suma ponderata a elasticitatilor venitului
 yhelast(c,h)   Elasticitatea veniturilor gospodariilor normalizata
 beta(c,h)      Buget marginal ponderi
 hexps(h)       Cheltuiala de subzistenta
 frisch(h)      Elasticitatea utilitatii marginale a venitului
 qcdconst(c,h)  Consumul de subzistenta - volum

 ;

* #### Initializare

 YH0(h)       = SAM("total",h) ;
 YHWOR0(h)    = SAM(h,"row") ;
 HEXP0(h)     = SUM(c,SAM(c,h)) ;

 QCH0(c,h)$PAC0(c)    = SAM(c,h)/PAC0(c) ;

 SHH0(h)      = SAM("i_s",h)/(YH0(h)-SAM("tven",h)) ;

 SADJ0        = 1 ;

 shh(h)       = SAM("i_s",h)/(SAM("total",h) - SAM("tven",h)) ;


* ## Cheltuiala de consum

 comhsh(c,h)$SUM(cp,SAM(cp,h))
                 = SAM(c,h)/SUM(cp,SAM(cp,h)) ;

 alphah(c,h)$SUM(cp,SAM(cp,h))
                 = SAM(c,h)/(SUM(cp,SAM(cp,h))) ;

* # Stone-Geary
* Suma ponderata a elasticitatilor egala cu 1

 sumelast(h)   = SUM(c, alphah(c,h)*ELASTY(c,h)) ;

 yhelast(c,h)$sumelast(h)
               = ELASTY(c,h)/sumelast(h) ;

 yhelast(c,h)$(alphah(c,h) eq 0)  = 0 ;

 beta(c,h)     = yhelast(c,h)*alphah(c,h) ;

 frisch(h)     = ELASTMU(h,"frisc") ;

 qcdconst(c,h)$(PAC0(c) and frisch(h) and beta(c,h))
               = [HEXP0(h)/PAC0(c)]
                    *(alphah(c,h)+(beta(c,h)/frisch(h))) ;

 hexps(h)      = SUM(c,qcdconst(c,h) * PAC0(c)) ;

Parameter
 betaCHK(h)      verificare beta
 alphahCHK(h)    verificare suma ;

 betaCHK(h)    = SUM(c,beta(c,h)) ;

 alphahCHK(h)  = Sum[c, alphah(c,h)] ;


* ######## BLOCUL intreprinderilor

PARAMETERS

 YE0(e)         Venitul intreprinderii e
 YEWOR0(e)      Venitul intreprinderii e de la restul lumii
 SE0(e)         Pondere venit economisit de intreprinderea e (dupa taxare) initial
 SEADJ0         Factor scalare pentru rata de economisire

 se(e)         Pondere venit economisit de intreprinderea e (dupa taxare)
 hesh(h,e)     Ponderi venituri primite de gospodarii de la intreprinderi
 ;

* #### Initializare

 YE0(e)       = SAM("total",e) ;

 SE0(e)      = SAM("i_s",e)/(YE0(e)-SAM("tven",e)) ;
 YEWOR0(e)   = SAM(e,"row");

 se(e)       = SAM("i_s",e)/(SAM("total",e) - SAM("tven",e)) ;
 SEADJ0       =1 ;

 hesh(h,e)      = SAM(h,e)/(SAM("total",e)) ;


* ######## BLOCUL Guvernului

* #### Taxe

PARAMETERS
* ## Rate de taxare initiale


 TIM0(c)        Rata taxa import pentru bunul c
 TVA0(c)         Rata taxa pe valoarea adaugata
 TP0(a)         Rata taxa productie activitatea a
 TYH0(h)        Rata taxare directa gospodarii h
 TYE0(e)        Rata taxare directa intreprinderi e
 TC0(f)         Contributia sociala pe munca
 TTH0(h)        Transferuri sociale de la guvern catre gospodarii
 TTE0(e)        Transferuri de la guvern la firme
 TROW0(g)       Transferuri catre guvern de la restul lumii

* ## Rate de taxare


 tim(c)          Rata taxa import pentru bunul c
 tva(c)          Rata taxa pe valoarea adaugata
 tp(a)          Rata taxa productie activitatea a
 tyh(h)         Rata taxare directa gospodarii h
 tye(e)         Rata taxare directa intreprinderi e
 tc(f)          Contributia sociala pe munca
 tth(h)         Transferuri sociale de la guvern catre gospodarii
 tte(e)         Transferuri de la guvern la firme
 trow(g)        Transferuri catre guvern de la restul lumii

* ## Factori scalare rate taxare

 TIMADJ0         Factor scalare Rata taxa import
 TVAADJ0         Factor scalare TVA
 TPADJ0         Factor scalare taxa productie
 TYHADJ0        Factor scalare taxare directa gospodarii
 TYEADJ0        Factor scalare taxare directa firme
 TCADJ0         Factor scalare contributii sociale
 TTHADJ0        Factor scalare transferuri sociale de la guvern catre gospodarii
 TTEADJ0        Factor scalare transferuri de la guvern catre firme
 TROWADJ0       Factor scalare transferuri catre guvern de la restul lumii

* ## Venituri bugetare din taxe initial

 IMTAX0         Venituri din taxa pe import
 PTAX0          Venituri din taxa pe productie
 DTAX0          Venituri din taxarea directa gospodarii si firme
 TVATAX0        Venituri din TVA
 CTAX0          Venituri din contributii sociale
 HTRAN0         Transferuri sociale de la guvern catre gospodarii
 ETRAN0         Transferuri de la guvern la firme
 ROWTRAN0       Transferuri catre guvern de la restul lumii
 PIB0           Produsul intern brut
  ;

* ## Initializare

* ## rate initiale

 TIM0(c)$cm(c) = SAM("imptax",c)/SAM("row",c) ;

 TVA0(c)$(SAM(c,"total")>0)     = SAM("saltax",c)/(SUM(a,SAM(c,a))
                                + SUM(h,SAM(c,h))
                                + SAM(c,"govt")
                                + SAM(c,"i_s")
                                - SAM(c,"amed")
                                - SAM("saltax",c) ) ;

 TP0(a)$(SAM("total",a)>0)    = SAM("prodtax",a)/SAM("total",a) ;

 TYH0(h)      = SAM("tven",h)/SAM("total",h) ;

 TYE0(e)      = SAM("tven",e)/SAM("total",e) ;

 TC0(f)      = SAM("tcontrib",f)/SAM("total",f) ;

 TTH0(h)     =  SAM(h,"govt") ;
 TTE0(e)     =  SAM(e,"govt") ;
 TROW0(g)    =  SAM(g,"row");

* ## rate

 tim(c)$cm(c) = SAM("imptax",c)/SAM("row",c) ;

 tva(c)$(SAM(c,"total")>0)        = SAM("saltax",c)/(SUM(a,SAM(c,a))
                                + SUM(h,SAM(c,h))
                                + SAM(c,"govt")
                                + SAM(c,"i_s")
                                - SAM(c,"amed")
                                - SAM("saltax",c) ) ;

 tp(a)$(SAM("total",a)>0)     = SAM("prodtax",a)/SAM("total",a) ;

 tyh(h)    = SAM("tven",h)/SAM("total",h) ;
 tye(e)    = SAM("tven",e)/SAM("total",e) ;
 tc(f)    = SAM("tcontrib",f)/SAM("total",f) ;
 tth(h)     =  SAM(h,"govt") ;
 tte(e)     =  SAM(e,"govt") ;
 trow(g)       =  SAM(g,"row") ;

* ## factori scalare

 TIMADJ0      = 1 ;
 TVAADJ0      = 1 ;
 TPADJ0      = 1 ;
 TYHADJ0     = 1 ;
 TYEADJ0     = 1 ;
 TCADJ0      = 1 ;
 TTHADJ0     = 1 ;
 TTEADJ0     = 1 ;
 TROWADJ0    = 1 ;

* ## Venituri din taxe initial

 IMTAX0       = SUM(c,SAM("imptax",c)) ;
 TVATAX0       = SUM(c,SAM("saltax",c)) ;
 PTAX0       = SUM(a,SAM("prodtax",a)) ;
 DTAX0       = SUM(h,SAM("tven",h)) + SUM(e,SAM("tven",e));
 CTAX0       = SUM(f,SAM("tcontrib",f)) ;
 HTRAN0      = SUM(h, SAM(h,"govt")) ;
 ETRAN0      = SUM(e, SAM(e,"govt")) ;
 ROWTRAN0    = SUM(g, SAM(g,"row"))  ;
 PIB0        = SUM(a,SUM(c,SAM(a,c)))-SUM(c,SUM(a,SAM(c,a)))+SUM(a, SAM("cmed",a))+SUM(c,SAM("saltax",c))  ;

PARAMETERS

 YG0            Venit la buget

 QCG0(c)        Cererea guvernamentala pentru bunuri si servicii

 EG0            Cheltuiala bugetara

 QCGADJ0        Factor scalare pt Cererea guvernamentala pentru bunuri si servicii

 DEFGOV0        Deficit- excedent bugetar

 qgdconst(c)    Volumul cererii guvernamentale pentru bunuri si servicii

  ;

* ## Initializare

 YG0         = SAM("total","govt") ;

 QCG0(c)$PAC0(c)    = SAM(c,"govt")/PAC0(c) ;
* QGD0("cmed")=0;
 EG0         = YG0 - SAM("i_s","govt") ;

 QCGADJ0     = 1 ;

 DEFGOV0     = SAM("i_s","govt") ;

 qgdconst(c)$PAC0(c)  = SAM(c,"govt")/PAC0(c) ;
* qgdconst("cmed")=0;

* ######## BLOCUL mediului

PARAMETERS

 MPE0          Poluarea
 MPCOM0(c)     Poluarea asociata pentru fiecare bun
 MEE0          Cheltuieli pentu reducerea poluarii
 MEG0          Cheltuieli ale guvernului pentru mediu reducere poluarii
 MEREST0(c)     Poluarea nespalata se va regasi doar la cmed
 coefghg0(c)       Coeficientul de emisie
 varghg(c)       Reducerea coeficientului de emisie estimat exogen
 MEGADJ0        Factor scalare pentru cheltuielile guvernului pentru reducerea poluarii
 ;

* #### Initializare

 MPE0       = SUM(c,SAM("med",c)) ;
 MPCOM0(c)      =SAM("med",c);
* MP0(m)       = QX0("amed");
 MEE0       = SUM(a,SAM("med",a));
* MEE0(a)       = SAM("med",a);
 MEG0       = SAM("cmed", "govt");
 MEREST0(c)$ cme(c)=0;
 MEREST0(c)$ cmen(c)=MPE0+MEE0-MEG0;
* varghg = MEDIU("fi");
  varghg(c)=0;
 coefghg0(c)$ cme(c) =MPCOM0(c)/SUM(a,SAM(a,c)) ;
 coefghg0(c)$ cmen(c)=0;
 MEGADJ0     = 1 ;

* ######## BLOCUL de capital

PARAMETERS

 TOTSAV0       Economisirea totala

 KAPWOR0       Balanta contului curent

 QINVD0(c)     Investitii pentru bunuri si servicii

 INVEST0       Total cheltuiala pentru investitii

 IADJ0         Factor scalare pentru investitii

 qinvdconst(c) Volumul cererii pentru investitii

  ;

* ## Initializare

 TOTSAV0       = SAM("i_s","total") ;

 KAPWOR0       = SAM("i_s","row") ;

 QINVD0(c)$PAC0(c)     = SAM(c,"i_s")/PAC0(c) ;

 INVEST0       = SAM("total","i_s") ;

 IADJ0         = 1 ;

 qinvdconst(c)$PAC0(c)   = SAM(c,"i_s")/PAC0(c) ;

* ######## BLOCUL de clearing

PARAMETERS

* #### variabila Slack verificare

 WALRAS0      variabila slack legea Walras

  ;

 WALRAS0   = 0 ;

  ;

*################## FINAL CALIBRARE model ##############################

*################## 7. Declaratii variabile ########################

 Free Variables

* ######## Blocul comertului extern

* #### Cursul de schimb

 ER           Cursul de schimb

* #### Blocul exporturilor

 PWEX(c)       Pretul exporturilor
 PEX(c)        Pretul domestic al exporturilor din bunul c
 PD(c)         Pretul de consum pentru oferta domestica din bunul c

 QEX(c)        Productia domestica exportata din bunul c
 QD(c)         Cererea interna pentru bunul c


* #### Blocul exporturilor

 PWIM(c)       Pretul importurilor
 PIM(c)         Pretul domestic al importurilor concurente pentru bunul c

 QIM(c)        Importul din bunul c
 QC(c)        Oferta pentru bunul compozit c

* ######## Blocul preturilor bunurilor si serviciilor

 PPS(c)       Pretul de productie al bunului compozit c
 PAC(c)       Pretul de achizitie al bunului c
 PPC(c)       Pretul de productie domestic al bunului compozit  c

 CPI          Indicele preturilor de consum
 PPI          Indicele preturilor de productie

* ######## Blocul productiei

 PP(a)        Pretul compozit al productiei activitatii a
 PVA(a)       Pretul de vanzare pentru productia activitatii a
 QP(a)        Productia domestica a activitatii a

 WF(f)        Pretul factorului f
 WFDIST(f,a)  Ponderi ale preturilor factorilor pe activitati
 FD(f,a)      Cererea pentru factorul f in activitatea a
 FS(f)        Oferta pentru factorul f

 WFL          Pretul muncii
 WFDISTL(a)   Ponderi ale pretului muncii
 FDL(a)       Cererea de munca
 FSL          Oferta de munca

 QINTD(c)     Cerere pentru consum intermediar din bunul c

 QPC(c)       Productia domestica din bunul c

* ######## Blocul factorilor

 YF(f)        Venit din factorul f
 YFDIST(f)    Venitul factorilor dupa depreciere
 YFWOR(f)     Venit din factori de la restul lumii

* ######## Blocul gospodariilor

 YH(h)        Venitul gospodariei h
 YHWOR(h)     Remitente pentru gospodaria h
 HEXP(h)      Cheltuiala de consum pentru gospodaria h
 QCH(c,h)     Consumul gospodariei h din bunul c

* ######## Blocul intreprinderilor

 YE(e)        Venit pentru intreprinderea e
 YEWOR(e)     Venit de la restul lumii pentru intreprinderea e

* ######## Blocul guvernamental

* #### Taxe

 IMTAX        Venituri din taxa pe import
 TVATAX       Venituri din TVA
 PTAX         Venituri din taxa pe productie
 DTAX         Venituri din taxarea directa gospodarii si firme
 CTAX         Venituri din contributii sociale
 HTRAN        Transferuri sociale de la guvern catre gospodarii
 ETRAN        Transferuri de la guvern la firme
 ROWTRAN      Transferuri catre guvern de la restul lumii
 TIMADJ       Factor scalare Rata taxa import
 TVAADJ       Factor scalare TVA
 TPADJ        Factor scalare taxa productie
 TYHADJ       Factor scalare taxare directa gospodarii
 TYEADJ       Factor scalare taxare directa firme
 TCADJ        Factor scalare contributii sociale
 TTHADJ       Factor scalare transferuri sociale de la guvern catre gospodarii
 TTEADJ       Factor scalare transferuri de la guvern catre firme
 TROWADJ      Factor scalare transferuri catre guvern de la restul lumii
 PIB          Produsul intern brut

* #### Venituri si cheltuieli bugetare

 YG           Venit bugetar

 QCG(c)       Cererea pentru consum guvernamental  - bunul c

 EG           Cheltuiala bugetara

 QCGADJ       Factor scalare cerere guvernamentala pentru consum

 DEFGOV       Deficit - excedent bugetar

* ######## BLOCUL mediului


 MPE          Poluarea
 MEE          Cheltuieli pentu reducerea poluarii
 MPCOM(c)     Poluarea asociata pentru fiecare bun sau serviciu
 MEREST(c)    Spalarea poluarii
 MEG          Cheltuiala guvernului pentru mediu reducerea poluarii
 MEGADJ       Factor scalare pentru cheltuiala guvernului cu poluarea
 coefghg(c)   Coeficientul de emisie modificat


* ######## Blocul de capital

 TOTSAV       Economisirea totala

 KAPWOR       Balanta contului curent

 SADJ         Factor sclare rata de economisire
 SEADJ        Factor scalare economisire intreprinderi
 QINVD(c)     Cererea pentru investitii bunul c

 INVEST       Cheltuieli totale investitii

 IADJ         Factor scalare investitii

* ######## Blocul de clearing

 WALRAS       Variabila slack   Walras

        ;

*################## 8. Initializare ####################

* #######Blocul preturilor

 PD.L(c)      = PD0(c) ;

 PIM.L(c)     = PIM0(c) ;
 PEX.L(c)     = PEX0(c) ;

 PP.L(a)      = PP0(a) ;
 PPC.L(c)     = PPC0(c) ;

 PPS.L(c)     = PPS0(c) ;

 ER.L         = ER0 ;

* #######Blocul comertului

*###Exporturi

 PWEX.L(c)     = PWEX0(c) ;

 QD.L(c)      = (SUM(a,SAM(a,c))/PD.L(c)) - QEX0(c) ;

 QEX.L(ce)$gamma(ce)    = QD.L(ce)*((PEX.L(ce)/PD.L(ce))*((1-gamma(ce))
                                 /gamma(ce)))**(1/(rhot(ce)-1)) ;

*###Importuri
 PWIM.L(c)     = PWIM0(c) ;

 QC.L(c)      = QC0(c) ;

 QIM.L(c)$(cd(c) AND cm(c))
              = QD.L(c)*((PD.L(c)/PIM.L(c))
                        *(delta(c)/(1-delta(c))))**(1/(1+rhoc(c))) ;
 QIM.L(c)$(cdn(c) AND cm(c))
              = QC.L(c) ;


* ####Preturi

 PAC.L(c)     = PPS0(c) * (1 + (TVAADJ0 * tva(c))) ;

 CPI.L        = CPI0 ;
 PPI.L        = PPI0 ;

* #####Blocul productiei

 PVA.L(a)    = PVA0(a) ;

 QP.L(a)     = QP0(a) ;

 FD.L(f,a)  = FD0(f,a) ;
 FDL.L(a)   = FDL0(a);
 FS.L(f)    = FS0(f) ;
 FSL.L      = FSL0 ;
 WF.L(f)    = WF0(f) ;
 WFL.L      = WFL0 ;
 WFDIST.L(f,a) = WFDIST0(f,a) ;
 WFDISTL.L(a)  = WFDISTL0(a);
* Consum intermediar

 QINTD.L(c)   = QINTD0(c) ;

* Productie

 QPC.L(c)     = QPC0(c) ;

* #####Blocul factorilor
 YFWOR.L(f)   = YFWOR0(f) ;
 YF.L(f)      = SUM(a,WF.L(f)*WFDIST.L(f,a)*FD.L(f,a)) + YFWOR.L(f) ;
 YFDIST.L(f)  = (YF.L(f) - (deprec(f)*YF.L(f))) ;

* #####Blocul intreprinderilor
 TTEADJ.L     = TTEADJ0 ;
 SEADJ.L      = SEADJ0 ;
 YEWOR.L(e)   = YEWOR0(e) ;
 YE.L(e)      = SUM(f,evash(f) * YFDIST.L(f))+ YEWOR.L(e)+ TTEADJ.L*tte(e) ;

* ######Blocul gospodariilor
 YHWOR.L(h)   = YHWOR0(h);
 TTHADJ.L     = TTHADJ0 ;

 YH.L(h)      = SUM(f,hvash(h,f) * YFDIST.L(f)) +  SUM(e,hesh(h,e)*YE.L(e)) + TTHADJ.L*tth(h)  + YHWOR.L(h);

 SADJ.L       = SADJ0 ;

 HEXP.L(h)    = ((YH.L(h)*(1-(TYHADJ0*tyh(h))))*(1-(SADJ.L*shh(h)))) ;

 QCH.L(c,h)   = comhsh(c,h)*HEXP.L(h)/PAC.L(c) ;

* #####Blocul guvernamental

 TIMADJ.L      = TIMADJ0 ;
 TVAADJ.L      = TVAADJ0 ;
 TPADJ.L      = TPADJ0 ;
 TYHADJ.L     = TYHADJ0 ;
 TYEADJ.L     = TYEADJ0 ;
 TCADJ.L      = TCADJ0 ;

 TROWADJ.L    = TROWADJ0 ;

 IMTAX.L       = SUM(c,TIMADJ.L*tim(c)*PWIM.L(c)*ER.L*QIM.L(c)) ;
 TVATAX.L       = SUM(c,TVAADJ.L*tva(c)*PPS.L(c)*QC.L(c)) ;
 PTAX.L       = SUM(a,TPADJ.L*tp(a)*PP.L(a)*QP.L(a)) ;
 DTAX.L       = SUM(h,TYHADJ.L*tyh(h)*YH.L(h)) + SUM(e,TYEADJ.L*tye(e)*YE.L(e));
 CTAX.L       = SUM(f,TCADJ.L*tc(f)*YF.L(f)) ;
 ROWTRAN.L    = SUM(g,TROWADJ.L*trow(g)) ;

 YG.L         = IMTAX.L  + TVATAX.L + PTAX.L + DTAX.L + CTAX.L + ROWTRAN.L + SUM(f,gvash(f) * YFDIST.L(f));

 QCG.L(c)     = QCGADJ0*qgdconst(c) ;
 HTRAN.L      = SUM(h,TTHADJ.L*tth(h)) ;

 ETRAN.L      =  SUM(e,TTEADJ.L*tte(e));
 EG.L         = SUM(c,QCG.L(c)*PAC.L(c)) + HTRAN.L + ETRAN.L - QCG.L("cmed")*PAC.L("cmed");

 QCGADJ.L    = QCGADJ0 ;

 DEFGOV.L     = DEFGOV0 ;


* #####Blocul de mediu
 MPE.L       =      QP.L("amed")*PP.L("amed");
 MEE.L    =    -  QINTD.L("cmed")*PAC.L("cmed");
 PIB.L        = SUM(a, QP.L(a)*PP.L(a))- SUM(c, QINTD.L(c)*PAC.L(c))+ SUM(c,TVAADJ.L*tva(c)*PPS.L(c)*QC.L(c)) - MEE.L - MPE.L ;
 coefghg.L(c)  =    coefghg0(c) + varghg(c);
 MPCOM.L(c)      =   coefghg.L(c)* QPC.L(c)*PPC.L(c);

 MEGADJ.L=MEGADJ0;
 MEG.L=QCG.L("cmed")*PAC.L("cmed");
 MEREST.L(c)$ cme(c)=  0;
 MEREST.L(c)$ cmen(c)= MPE.L+ MEE.L-MEG.L;
* #####Blocul de capital

 KAPWOR.L     = SUM(cm,PWIM.L(cm)*QIM.L(cm))
                 - SUM(ce,PWEX.L(ce)*QEX.L(ce))- ROWTRAN.L - SUM(e, YEWOR.L(e))
                 - SUM(h,YHWOR.L(h)) - SUM(f, YFWOR.L(f));

 TOTSAV.L     = SUM(h,YH.L(h)*(1-(TYHADJ.L*tyh(h)))*(SADJ.L*shh(h)))
                   + SUM(e,YE.L(e)*(1-(TYEADJ.L*tye(e)))*(SEADJ.L*se(e)))
                   + SUM(f,deprec(f)*YF.L(f))
                   + DEFGOV.L
                   + (KAPWOR.L*ER.L) ;

 IADJ.L       = IADJ0 ;

 QINVD.L(c)   = (IADJ.L*qinvdconst(c)) ;

 INVEST.L     = SUM(c,PAC.L(c)*QINVD.L(c)) ;

* ######Blocul de clearing

 WALRAS.L     = WALRAS0 ;


*################## 9. SAM din nou ####################

 OPTION DECIMALS = 6 ;

 ASAM1("COMMDTY","ACTIVITY") = SUM(c,QINTD.L(c)*PAC.L(c)+ QPC.L(c)*coefghg.L(c)*PPC.L(c)) ;
 ASAM1("COMMDTY","HHOLDS")   = SUM((c,h), QCH.L(c,h)*PAC.L(c)) ;
 ASAM1("COMMDTY","GOVTN")    = SUM(c,QCG.L(c)*PAC.L(c)) ;
 ASAM1("COMMDTY","KAPITAL")  = SUM(c,QINVD.L(c)*PAC.L(c)) ;
 ASAM1("COMMDTY","WORLD")    = SUM(c,PWEX.L(c)*QEX.L(c)*ER.L) ;
 ASAM1("COMMDTY","ENVIR")    = MPE.L+MEE.L-MEG.L ;

 ASAM1("ENVIR","COMMDTY")    = MPE.L ;
 ASAM1("ENVIR","ACTIVITY")   = MEE.L;
 ASAM1("ENVIR","GOVTN")      = -MEG.L;
 ASAM1("ACTIVITY","COMMDTY") = SUM(a,PP.L(a)*QP.L(a)) ;

 ASAM1("VALUAD","ACTIVITY")  = SUM((f,a),WF.L(f)*WFDIST.L(f,a)*FD.L(f,a)) ;
 ASAM1("VALUAD","WORLD")     = SUM(f,YFWOR.L(f)) ;

 ASAM1("HHOLDS","VALUAD")    = SUM((h,f),hvash(h,f) * YFDIST.L(f)) ;
 ASAM1("HHOLDS","ENTER")     = SUM((h,e),hesh(h,e)*YE.L(e)) ;

 ASAM1("HHOLDS","GOVTN")     = SUM(h,TTHADJ.L*tth(h)) ;

 ASAM1("HHOLDS","WORLD")     = SUM(h,YHWOR.L(h)) ;
 ASAM1("ENTER","VALUAD")     = SUM(f,evash(f) * YFDIST.L(f)) ;
 ASAM1("ENTER","GOVTN")      = SUM(e,TTEADJ.L*tte(e)) ;

 ASAM1("ENTER","WORLD")      = SUM(e,YEWOR.L(e)) ;
 ASAM1("GOVTN","COMMDTY")    = SUM(c,TIMADJ.L*tim(c)*PWIM.L(c)*QIM.L(c)*ER.L)
                                  + SUM(c,TVAADJ.L*tva(c)*PPS.L(c)*QC.L(c)) ;
 ASAM1("GOVTN","ACTIVITY")   = SUM(a,TPADJ.L*tp(a)*PP.L(a)*QP.L(a)) ;

 ASAM1("GOVTN","VALUAD")     =  SUM(f,gvash(f) * YFDIST.L(f))
                                  + SUM(f,TCADJ.L*tc(f)*YF.L(f)) ;
 ASAM1("GOVTN","HHOLDS")     = SUM(h,TYHADJ.L*tyh(h)*YH.L(h)) ;

 ASAM1("GOVTN","ENTER")        = SUM(e,TYEADJ.L*tye(e)*YE.L(e)) ;
 ASAM1("GOVTN","WORLD")        = ROWTRAN.L ;
 ASAM1("KAPITAL","VALUAD")   = SUM(f,YF.L(f)*deprec(f))
                                   - SUM(f,TCADJ.L*tc(f)*YF.L(f));
 ASAM1("KAPITAL","HHOLDS")   = SUM(h,(YH.L(h)*(1-(TYHADJ.L*tyh(h))))
                                          *(SADJ.L*shh(h))) ;
 ASAM1("KAPITAL","ENTER")      = SUM(e,(YE.L(e)*(1-(TYEADJ.L*tye(e))))
                                          *(SEADJ.L*se(e))) ;

 ASAM1("KAPITAL","GOVTN")    = DEFGOV.L ;
 ASAM1("KAPITAL","WORLD")    = (KAPWOR.L*ER.L) ;

 ASAM1("WORLD","COMMDTY")    = SUM(c,PWIM.L(c)*QIM.L(c)*ER.L) ;

 ASAM1("TOTALS",ssn)         = SUM(ssnp,ASAM1(ssnp,ssn)) ;
 ASAM1(ssn,"TOTALS")         = SUM(ssnp,ASAM1(ssn,ssnp)) ;


 PARAMETER
 CHECK1             Verificare
 ASAM1CHK(ss,ss)    Diferente
  ;

 CHECK1 = SUM(ssn,(ABS(ASAM1(ssn,"TOTALS")-ASAM1("TOTALS",ssn)))) ;

 ASAM1CHK(ss,ss)  = ASAM0(ss,ss) - ASAM1(ss,ss) ;

 OPTION DECIMALS=6 ;

 DISPLAY CHECK1, ASAM1, ASAM1CHK ;

 ABORT $(CHECK1 GT 0.000005)
 "Diferente linii coloane", CHECK1, ASAM1 ;

*####################################################################

*################## 10. Declararea ecuatiilor modelului ############

EQUATIONS

* ###Blocul comertului

* #### Blocul exporturilor

 PEXDEF(c)       Pretul domestic pentru exportul din bunul c
 CET(c)          Functia CET pentru productia domestica
 ESUPPLY(c)      Functia ofertei pentru export
 CETALT(c)       Functia CET pentru productia domestica neexportata sau doar exportata

* #### Blocul importurilor

 PIMDEF(c)       Pretul domestic al importurilor competitive din bunul c
 ARMINGTON(c)    Functia agregare bunuri compozite
 COSTMIN(c)      Functia de minimizare a costurilor pentru bunurile compozite
 ARMALT(c)       Functia agregare pentru bunuri neimportate sau doar importatate

* #####Blocul preturilor

 PPSDEF(c)       Pretul de productie pentru bunul compozit c
 PACDEF(c)       Pretul de achizitie pentru bunul compozit c
 PPCDEF(c)       Pretul de productie pentru productia domestica din bunuri compozite

 CPIDEF          Indicele preturilor de consum
 PPIDEF          Indicele preturilor de productie

* ######Blocul productiei

 PPDEF(a)        Pretul compozit al productiei activitatii a

* Cobb Douglas /CES

  PVADEF(a)       Pretul de vanzare pentru productia activitatii a
* PRODFN(a)       Functiile de productie pentru activitatile a
* PROFITMAX(f,a)  Conditia de ordinul I pentru maximizarea profiturilor
  PRODFNL(a)       Functiile de productie pentru activitatile a
  PROFITMAXK(a)    Conditia de ordinul I pentru maximizarea profiturilor
  PROFITMAXL(a)    Conditia de ordinul I pentru maximizarea profiturilor
  PROFITMAXL3(f,a) Conditia de ordinul I pentru minimizarea costurilor
  PRODFNM(a)       Productia de poluanti

* Cerere consum intermediar

 QINTDEQ(c)      Cererea pentru consum intermediar din bunul c

* Productia

 COMOUT(c)       Productia domestica pentru bunul c

* #####Blocul mediului
 MPEEQ          Poluarea
 MEEEQ          Cheltuieli pentru reducerea poluarii
 MERESTEQR(c)   Spalarea poluarii
 MERESTEQM(c)   Spalarea poluarii
 COEF(c)        coeficientul de emisie
* ######Blocul factorilor

 YFEQ(f)         Venitul factorilor
 YFDISTEQ(f)     Venitul factorilor dupa depreciere

* ###Blocul gospodariilor

 YHEQ(h)         Venitul gospodariilor
 HEXPEQ(h)       Cheltuiala de consum a gospodariilor
 QCHEQ(c,h)      Functie consum cheltuieli liniare Stone -Geary

* #####Blocul intreprinderilor

 YEEQ(e)         Venitul intreprinderilor

* ###Blocul guvernamental

 IMTAXEQ          Venituri din taxa pe import
 TVATAXEQ          Venituri din TVA
 PTAXEQ          Venituri din taxa pe productie
 DTAXEQ          Venituri din taxarea directa gospodarii si firme
 CTAXEQ          Venituri din contributii sociale
 HTRANEQ         Transferuri sociale de la guvern catre gospodarii
 ETRANEQ         Transferuri de la guvern la firme
 ROWTRANEQ       Transferuri catre guvern de la restul lumii


 YGEQ            Venit bugetar
 QCGEQ(c)        Cererea pentru consum guvernamental  - bunul c
 EGEQ            Cheltuiala bugetara
* QGDEQM(c)       Cheltuieli antipoluare guvern
 MEGEQ          Cheltuiala guvernului pentru reducerea poluarii
 PIBEQ          Produsul intern brut
* #######Blocul de capital

 TOTSAVEQ        Economisirea totala

 QINVDEQ(c)      Cererea volum pentru investitii bunul c
 INVESTEQ        Cheltuieli totale investitii

* ######Blocul de clearing

 FMEQUIL(f)      Echilibrul pe piata factorilor
 QEQUIL(c)       Echilibrul pe piata bunurilor si serviciilor
 DEFGOVEQ        Echilibrul guvernamental
 KAPEQUIL        Balanta contului curent
 WALRASEQ        Echilibrul economiilor si investitiilor

   ;

*####################################################################
*################## 11. Ecuatiile modelului###################

* #####Blocul comertului

* #### Exporturi

 PEXDEF(c)$ce(c)..  PEX(c) =E= PWEX(c) * ER  ;

 CET(c)$(cd(c) AND ce(c))..
                  QPC(c) =E= at(c)*(gamma(c)*QEX(c)**rhot(c) +
                                 (1-gamma(c))*QD(c)**rhot(c))**(1/rhot(c)) ;

 ESUPPLY(c)$(cd(c) AND ce(c))..
                   QEX(c) =E= QD(c)*((PEX(c)/PD(c))*((1-gamma(c))
                                 /gamma(c)))**(1/(rhot(c)-1)) ;

 CETALT(c)$((cd(c) AND cen(c)) OR (cdn(c) AND ce(c)))..
                  QPC(c) =E= QD(c) + QEX(c) ;

* #### Importuri

 PIMDEF(c)$cm(c)..  PIM(c) =E= (PWIM(c) *(1 + (TIMADJ * tim(c)))) * ER ;

 ARMINGTON(c)$(cx(c) AND cm(c))..
                  QC(c)  =E= ac(c)*(delta(c)*QIM(c)**(-rhoc(c)) +
                                 (1-delta(c))*QD(c)**(-rhoc(c)))**(-1/rhoc(c)) ;

 COSTMIN(c)$(cx(c) AND cm(c))..
                   QIM(c) =E= QD(c)*((PD(c)/PIM(c))*(delta(c)/
                                 (1-delta(c))))**(1/(1+rhoc(c))) ;

 ARMALT(c)$((cx(c) AND cmn(c)) OR (cxn(c) AND cm(c)))..
                    QC(c) =E= QD(c) + QIM(c) ;

* #####Blocul preturilor bunurilor

 PACDEF(c)$(cd(c) OR cm(c))..
                  PAC(c) =E= PPS(c) * (1 + (TVAADJ*tva(c))) ;

 PPSDEF(c)$(cd(c) OR cm(c))..
            PPS(c)*QC(c) =E= (PD(c)*QD(c))+(PIM(c)*QIM(c)) ;

 PPCDEF(c)$cx(c)..
           PPC(c)*QPC(c) =E= (PD(c)*QD(c)) + (PEX(c)*QEX(c))$ce(c) ;

 CPIDEF..            CPI =E= SUM(c,comtotsh(c)*PAC(c)) ;

 PPIDEF..            PPI =E= SUM(c,prodtotsh(c)*PD(c)) ;

* ###Blocul productiei

 PPDEF(a)..        PP(a) =E= SUM(c,iocqa(a,c)*PPC(c)) ;

* PRODFN(a)..       QX(a) =E= ad(a)*PROD(f,FD(f,a)**alpha(f,a)) ;

* PRODFN(a)$amen(a)..       QX(a) =E= adva(a)*(SUM(f,deltava(f,a)*FD(f,a)**(-rhova(a))))
*                                      **(-1/rhova(a)) ;

 PRODFNL(a)$amen(a)..       QP(a) =E= adva(a)*(deltava(a)*FD("fres",a)**(-rhova(a))+ (1-deltava(a))*FDL(a)**(-rhova(a)))
                                      **(-1/rhova(a)) ;


 COEF(c)..        coefghg(c)  =E=   coefghg0(c) + varghg(c);
 PRODFNM(a)$ame(a)..       QP(a) =E= SUM(c,coefghg(c)*QPC(c)*PPC(c));

* PROFITMAX(f,a)..  WF(f)*WFDIST(f,a)*(FD(f,a)**(rhova(a)+1))*(adva(a)**(rhova(a)))
*                         =E= (QX(a)**(rhova(a)+1))*PVA(a)*deltava(f,a) ;

 PROFITMAXK(a)..  WF("fres")*WFDIST("fres",a)*(FD("fres",a)**(rhova(a)+1))*(adva(a)**(rhova(a)))
                         =E= (QP(a)**(rhova(a)+1))*PVA(a)*deltava(a) ;

 PROFITMAXL(a)..  WFL*WFDISTL(a)*(FDL(a)**(rhova(a)+1))*(adva(a)**(rhova(a)))
                         =E= (QP(a)**(rhova(a)+1))*PVA(a)*(1-deltava(a)) ;


 QINTDEQ(c)..   QINTD(c) =E= SUM(a,iocoef(c,a)*QP(a))-iocoef(c,"amed")*QP("amed") ;

 PVADEF(a)..      PVA(a) =E= PP(a)*(1-(TPADJ*tp(a)))
                                     - SUM(c$cme(c),PAC(c) * iocoef(c,a)) ;

 COMOUT(c)..       QPC(c) =E= SUM(a,iocqa(a,c)*QP(a)) ;

 PROFITMAXL3(f,a)$ flab(f)..  WF(f)*WFDIST(f,a)*(FD(f,a)**(rhoval(a)+1))*(adval(a)**(rhoval(a)))
                              =E= (FDL(a)**(rhoval(a)+1))*WFL*deltaval(f,a) ;




* ####Blocul factorilor

 YFEQ(f)..         YF(f) =E= SUM(a,WF(f)*WFDIST(f,a)*FD(f,a)) + YFWOR(f) ;

 YFDISTEQ(f)..   YFDIST(f) =E= (YF(f) - (deprec(f)*YF(f))) ;

* #####Blocul mediului
 MPEEQ..       MPE =E= QP("amed")*PP("amed") ;
 MEEEQ..       MEE =E= -QINTD("cmed")*PAC("cmed") ;



* #####Blocul intreprinderilor

 YEEQ(e)..         YE(e) =E= SUM(f,evash(f) * YFDIST(f)) + YEWOR(e)+ TTEADJ*tte(e) ;


* #####Blocul gospodariilor

 YHEQ(h)..         YH(h) =E= SUM(f,hvash(h,f) * YFDIST(f)) +  SUM(e,hesh(h,e)*YE(e)) + TTHADJ*tth(h)  + YHWOR(h) ;

 HEXPEQ(h)..     HEXP(h) =E= ((YH(h)*(1-(TYHADJ*tyh(h))))
                               *(1-(SADJ*shh(h)))) ;

 QCHEQ(c,h)..
         PAC(c)*QCH(c,h) =E= [PAC(c)*qcdconst(c,h)]
                             + beta(c,h)
                             *{HEXP(h) - SUM[cp,PAC(cp)*qcdconst(cp,h)]} ;

* #####Blocul guvernamental

 IMTAXEQ..           IMTAX =E= SUM(c,TIMADJ*tim(c)*pwim(c)*ER*QIM(c)) ;

 TVATAXEQ..           TVATAX =E= SUM{c,TVAADJ *tva(c) * PPS(c)
                                 *[QINTD(c) + SUM(h,QCH(c,h))
                                   + QCG(c) + QINVD(c)]} ;

 PTAXEQ..           PTAX =E= SUM(a,TPADJ*tp(a)*PP(a)*QP(a)) ;

 DTAXEQ..           DTAX =E=  SUM(h,TYHADJ*tyh(h)*YH(h)) + SUM(e,TYEADJ*tye(e)*YE(e)) ;

 CTAXEQ..           CTAX =E=  SUM(f,TCADJ*tc(f)*YF(f)) ;

 HTRANEQ..          HTRAN =E= SUM(h,TTHADJ*tth(h)) ;

 ETRANEQ..          ETRAN =E= SUM(e,TTEADJ*tte(e));

 ROWTRANEQ..        ROWTRAN =E= SUM(g,TROWADJ*trow(g)) ;

 YGEQ..               YG =E= IMTAX + TVATAX + PTAX + DTAX + CTAX + ROWTRAN + SUM(f,gvash(f) * YFDIST(f));

 QCGEQ(c)$qgdconst(c)..
                  QCG(c) =E= QCGADJ * qgdconst(c) ;
* QGDEQM(c)$cmen(c)..  QGD(c) =E=  0;

 MEGEQ..        MEG =E= QCG("cmed")* PAC("cmed");
 EGEQ..         EG =E= SUM(c,QCG(c)*PAC(c)) + HTRAN + ETRAN-MEG;
 PIBEQ..       PIB =E= SUM(a, QP(a)*PP(a))- SUM(c, QINTD(c)*PAC(c))+ SUM(c,TVAADJ*tva(c)*PPS(c)*QC(c)) - MEE- MPE ;

*poluare din nou
 MERESTEQR(c)$cme(c)..  MEREST(c) =E= 0;
 MERESTEQM(c)$cmen(c)..  MEREST(c) =E= MPE+MEE-MEG;

* ####Blocul de capital

 TOTSAVEQ..       TOTSAV =E= SUM(h,YH(h)*(1-(TYHADJ*tyh(h)))*(SADJ*shh(h)))
                               + SUM(e,YE(e)*(1-(TYEADJ*tye(e)))*(SEADJ*se(e)))
                               + SUM(f,deprec(f)*YF(f))
                               - SUM(f,TCADJ*tc(f)*YF(f))
                               + DEFGOV
                               + (KAPWOR*ER) ;

 QINVDEQ(c)$qinvdconst(c)..
                QINVD(c) =E= (IADJ*qinvdconst(c)) ;

 INVESTEQ..       INVEST =E= SUM(c,PAC(c)*QINVD(c)) ;

* ####Blocul de clearing

 FMEQUIL(f)..      FS(f) =E= SUM(a,FD(f,a)) ;

 QEQUIL(c)..       QC(c) =E= QINTD(c) + SUM(h, QCH(c,h)) + QCG(c) + QINVD(c)+ MEREST(c);

 DEFGOVEQ..       DEFGOV =E= YG - EG ;

 KAPEQUIL..       KAPWOR =E= SUM(cm,PWIM(cm)*QIM(cm))
                             - SUM(ce,PWEX(ce)*QEX(ce))- ROWTRAN - SUM(e, YEWOR(e))
                             - SUM(h,YHWOR(h)) - SUM(f, YFWOR(f)) ;

 WALRASEQ..       TOTSAV =E= INVEST + WALRAS ;

*####################################################################
*################## 12. Inchiderea modelului###################

* ER cursul de schimb fix, balanta contului curent echilibreaza (variabila)

 ER.FX            = ER0 ;
*  KAPWOR.FX        =KAPWOR0 ;
* Preturile externe fixate

 PWIM.FX(c)        = PWIM0(c) ;
 PWEX.FX(c)        = PWEX0(c) ;

* Investitii fixe, economisirea echilibreaza (variabila)

  SEADJ.FX         =SEADJ0;
  IADJ.FX         = IADJ0 ;


* Rate taxare fixe

 TIMADJ.FX         = TIMADJ0 ;
 TVAADJ.FX         = TVAADJ0 ;
 TPADJ.FX         = TPADJ0 ;
 TYHADJ.FX        = TYHADJ0 ;
 TYEADJ.FX        = TYEADJ0 ;
 TCADJ.FX         = TCADJ0 ;
 TTHADJ.FX        = TTHADJ0 ;
 TROWADJ.FX      = TROWADJ0 ;
*MEGADJ.FX         =MEGADJ0;
* TTEADJ.FX      =TTEADJ0;
* Cheltuiala de consum guvernamental fixa ca volum

 QCGADJ.FX        = QCGADJ0 ;
* EG.FX           =EG0;
* Deficitul bugetar fix

 DEFGOV.FX       = DEFGOV0 ;

*## Clearing factori

* toti factorii sunt mobili, exista somaj al fortei de munca

 FS.FX("fres")            = FS0("fres") ;
 FS.FX("flab2")            = FS0("flab2") ;
 FS.FX("flab3")            = FS0("flab3") ;

 WFDIST.FX(f,a)          = WFDIST0(f,a) ;
 WFDISTL.FX(a)           = WFDISTL0(a) ;
 WF.LO("fres")                = -inf ;
 WF.UP("fres")                = +inf ;

 WF.FX("flab1")          = WF0("flab1") ;
 WF.LO("flab2")                = -inf ;
 WF.UP("flab2")                = +inf ;
 WF.LO("flab3")                = -inf ;
 WF.UP("flab3")                = +inf ;

 FS.LO("flab1")          = -inf ;
 FS.UP("flab1")          = +inf ;

* Altele

 PPI.FX           = PPI0 ;

 YFWOR.FX(f)                = YFWOR0(f) ;
 YHWOR.FX(h)                = YHWOR0(h) ;
 YEWOR.FX(e)                = YEWOR0(e) ;

*####################################################################
*################## 13. Rezolvare model ####################


 OPTION DECIMALS = 6 ;

 Options limrow=500,limcol=0;

 option iterlim = 25000 ;

 option MCP           = PATH ;


Model roap_draft1 /


 PEXDEF.PEX
 CET
 ESUPPLY
 CETALT

 PIMDEF.PIM
 ARMINGTON
 COSTMIN
 ARMALT

 PPSDEF.PPS
 PACDEF.PAC
 PPCDEF.PPC

 CPIDEF
 PPIDEF

 PPDEF.PP
 PVADEF
 PRODFNL
 COEF
 PRODFNM
 PROFITMAXK
 PROFITMAXL
 QINTDEQ.QINTD
 COMOUT.QPC
 PROFITMAXL3

 YFEQ.YF
 YFDISTEQ.YFDIST

 MPEEQ.MPE
 MEEEQ.MEE
 MERESTEQR
 MERESTEQM

 YEEQ.YE

 YHEQ.YH
 HEXPEQ.HEXP
 QCHEQ.QCH

 IMTAXEQ.IMTAX
 TVATAXEQ.TVATAX
 PTAXEQ.PTAX
 DTAXEQ.DTAX
 CTAXEQ.CTAX
 HTRANEQ.HTRAN
 ETRANEQ.ETRAN
 ROWTRANEQ.ROWTRAN

 YGEQ.YG
 QCGEQ.QCG
* QGDEQM
 EGEQ
 MEGEQ
 PIBEQ
 TOTSAVEQ.TOTSAV
 QINVDEQ.QINVD
 INVESTEQ

 FMEQUIL
 QEQUIL.QC
 DEFGOVEQ
 KAPEQUIL
 WALRASEQ.WALRAS

             / ;

 PIM.FX(c)$(NOT cm(c))         = 0 ;
 PEX.FX(c)$(NOT ce(c))         = 0 ;

 QIM.FX(c)$(NOT cm(c))         = 0 ;
 QEX.FX(c)$(NOT ce(c))         = 0 ;

 FD.FX(f,a)$(NOT SAM(f,a))    = 0 ;
 QINVD.FX(c)$(NOT qinvdconst(c)) = 0 ;

 roap_draft1.HOLDFIXED   = 1 ;
 roap_draft1.TOLINFREP   = 0.000001 ;


Solve roap_draft1 using MCP ;


*################## 14. SAM din nou ####################

 ASAM2("COMMDTY","ACTIVITY") = SUM(c,QINTD.L(c)*PAC.L(c)+ QPC.L(c)*coefghg.L(c)*PPC.L(c)) ;


 ASAM2("COMMDTY","HHOLDS")   = SUM((c,h), QCH.L(c,h)*PAC.L(c)) ;
 ASAM2("COMMDTY","GOVTN")    = SUM(c,QCG.L(c)*PAC.L(c)) ;
 ASAM2("COMMDTY","KAPITAL")  = SUM(c,QINVD.L(c)*PAC.L(c)) ;
 ASAM2("COMMDTY","WORLD")    = SUM(c,PWEX.L(c)*QEX.L(c)*ER.L) ;

 ASAM2("COMMDTY","ENVIR")    = MPE.L+MEE.L-MEG.L ;

 ASAM2("ENVIR","COMMDTY")    = MPE.L ;
 ASAM2("ENVIR","ACTIVITY")    = MEE.L;
 ASAM2("ENVIR","GOVTN")      = -MEG.L;


 ASAM2("ACTIVITY","COMMDTY") = SUM(a,PP.L(a)*QP.L(a)) ;

 ASAM2("VALUAD","ACTIVITY")  = SUM((f,a),WF.L(f)*WFDIST.L(f,a)*FD.L(f,a)) ;
 ASAM2("VALUAD","WORLD")     = SUM(f,YFWOR.L(f)) ;

 ASAM2("HHOLDS","VALUAD")    = SUM((h,f),hvash(h,f) * YFDIST.L(f)) ;
 ASAM2("HHOLDS","ENTER")     = SUM((h,e),hesh(h,e)*YE.L(e)) ;

 ASAM2("HHOLDS","GOVTN")     = SUM(h,TTHADJ.L*tth(h)) ;

 ASAM2("HHOLDS","WORLD")     = SUM(h,YHWOR.L(h)) ;
 ASAM2("ENTER","VALUAD")     = SUM(f,evash(f) * YFDIST.L(f)) ;
 ASAM2("ENTER","GOVTN")      = SUM(e,TTEADJ.L*tte(e)) ;

 ASAM2("ENTER","WORLD")      = SUM(e,YEWOR.L(e)) ;
 ASAM2("GOVTN","COMMDTY")    = SUM(c,TIMADJ.L*tim(c)*PWIM.L(c)*QIM.L(c)*ER.L)
                                  + SUM(c,TVAADJ.L*tva(c)*PPS.L(c)*QC.L(c)) ;
 ASAM2("GOVTN","ACTIVITY")   = SUM(a,TPADJ.L*tp(a)*PP.L(a)*QP.L(a)) ;

 ASAM2("GOVTN","VALUAD")     =  SUM(f,gvash(f) * YFDIST.L(f))
                                  + SUM(f,TCADJ.L*tc(f)*YF.L(f)) ;
 ASAM2("GOVTN","HHOLDS")     = SUM(h,TYHADJ.L*tyh(h)*YH.L(h)) ;

 ASAM2("GOVTN","ENTER")        = SUM(e,TYEADJ.L*tye(e)*YE.L(e)) ;
 ASAM2("GOVTN","WORLD")        = ROWTRAN.L ;
 ASAM2("KAPITAL","VALUAD")   = SUM(f,YF.L(f)*deprec(f))
                                   - SUM(f,TCADJ.L*tc(f)*YF.L(f));
 ASAM2("KAPITAL","HHOLDS")   = SUM(h,(YH.L(h)*(1-(TYHADJ.L*tyh(h))))
                                          *(SADJ.L*shh(h))) ;
 ASAM2("KAPITAL","ENTER")      = SUM(e,(YE.L(e)*(1-(TYEADJ.L*tye(e))))
                                          *(SEADJ.L*se(e))) ;

 ASAM2("KAPITAL","GOVTN")    = DEFGOV.L ;
 ASAM2("KAPITAL","WORLD")    = (KAPWOR.L*ER.L) ;

 ASAM2("WORLD","COMMDTY")    = SUM(c,PWIM.L(c)*QIM.L(c)*ER.L) ;

 ASAM2("TOTALS",ssn)         = SUM(ssnp,ASAM2(ssnp,ssn)) ;
 ASAM2(ssn,"TOTALS")         = SUM(ssnp,ASAM2(ssn,ssnp)) ;


 PARAMETER
 CHECK2             Verificare
 ASAM2CHK(ss,ss)    Raport intre ASAM uri
  ;

 CHECK2 = SUM(ssn,(ABS(ASAM2(ssn,"TOTALS")-ASAM2("TOTALS",ssn)))) ;

 ASAM2CHK(ss,ssp)$ASAM1(ss,ssp)
                   = (ASAM2(ss,ssp))/ASAM1(ss,ssp) ;

 OPTION DECIMALS=6 ;

 DISPLAY CHECK2, ASAM2, ASAM2CHK ;

 ABORT $(CHECK2 GT 0.000005)
 "Diferente linii coloane", CHECK2, ASAM2 ;

 OPTION DECIMALS=5 ;

Execute_unload 'sammacro.gdx', ASAM2 ;
Execute_unload 'sammicro.gdx', SAM ;


*################## 15. Impactul FESI simulare ###############################

* datele pentru simulare sunt incarcate dintr-un alt fisier
$INCLUDE 2023_simulare_contractate.inc
*$INCLUDE 2023_simulare_contractate_alte.inc
*$INCLUDE 2023_simulare_plati_ani.inc

*########################### FINAL #####################################

